import Vue from "vue";
import Axios from "axios";
import { Message } from "iview";
import router from "../router";
//axios配置 start

//请求拦截
Axios.interceptors.request.use(
  config => {
    if (window.localStorage.getItem("token")) {
      Axios.defaults.headers.common["token"] = window.localStorage.getItem(
        "token"
      );
      Axios.defaults.headers.common["key"] = window.localStorage.getItem("key");
    }

    return config;
  },
  error => {
    Message.error({
      content: error,
      duration: 10,
      closable: true
    });
    return Promise.resolve(error);
  }
);

//响应拦截
Axios.interceptors.response.use(
  response => {
    return response;
  },
  error => {
    // 这里是返回状态码不为200时候的错误处理
    let status = error.response.status;

    if (status != 200) {
      const data = error.response.data;
      if (data && data.desc) {
        Message.error({
          content: data.desc,
          duration: 6,
          closable: true
        });
      }
    }
    // 登录失效 跳转登录页面
    if (status == 403 || status == 401) {
      router.push({
        name: "login"
      });
    }
    return Promise.reject(error);
  }
);

Axios.defaults.withCredentials = true; //允许跨域携带cookie
Axios.defaults.timeout = 10000; //超时时间
Axios.defaults.headers.common["X-Requested-With"] = "XMLHttpRequest"; //标识这是一个 ajax 请求

Vue.prototype.$http = Axios;

export default {
  install: function(Vue) {
    Object.defineProperty(Vue.prototype, "$http", {
      value: Axios
    });
  }
};
